@@ -10,8 +10,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2003/06/24';
+$VERSION = '0.04';
+$DATE = '2003/07/07';
 $FILE = __FILE__;
 
 ########
@@ -40,7 +40,7 @@ $FILE = __FILE__;
 
  Version: 
 
- Date: 2003/06/24
+ Date: 2003/07/07
 
  Prepared for: General Public 
 
@@ -90,10 +90,11 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      my $snl = 'File::SmartNL';
      use File::Package;
      my $fp = 'File::Package';
+     my $loaded = '';
  ^
  VO: ^
   N: UUT not loaded^
-  A: my $loaded = $fp->is_package_loaded('t::DataPort::DataFileI')^
+  A: $loaded = $fp->is_package_loaded('t::DataPort::DataFileI')^
   E:  ''^
  ok: 1^
 
@@ -363,11 +364,13 @@ Verify: DataFile.t^
 
     use File::Package;
     my $fp = 'File::Package';
+
+    my $loaded = '';
 ^
 
 VO: ^
  N: UUT not loaded^
- A: my $loaded = $fp->is_package_loaded('t::DataPort::DataFileI')^
+ A: $loaded = $fp->is_package_loaded('t::DataPort::DataFileI')^
  E:  ''^
 ok: 1^
 
